@@ -63,7 +63,7 @@ void EditDialog::setupDlg()
     btnIcon->setFixedSize(QSize(64, 64));
     btnIcon->setIconSize(QSize(64, 64));
 
-    QLabel *lab = new QLabel(wdg);
+    QLabel *lab = new QLabel(i18n("Insert the string for the emoticon.  If you want multiple strings, separate them by spaces."), wdg);
     lab->setWordWrap(true);
     vl->addWidget(lab);
     hb->addWidget(btnIcon);
@@ -84,7 +84,7 @@ void EditDialog::btnIconClicked()
     if (!url.isLocalFile())
         return;
 
-    emoticon = url.path();
+    emoticon = url.toLocalFile();
 
     if (emoticon.isEmpty())
         return;
@@ -263,7 +263,7 @@ void EmoticonList::installEmoticonTheme()
                                       i18n("Could Not Install Emoticon Theme"));
         return;
     }
-    QStringList installed = kEmoticons.installTheme(themeURL.path());
+    QStringList installed = kEmoticons.installTheme(themeURL.toLocalFile());
     for (int i = 0; i < installed.size(); i++)
         loadTheme(installed.at(i));
 }
@@ -317,7 +317,7 @@ void EmoticonList::editEmoticon()
 
     KEmoticonsTheme theme = emoMap.value(themeList->currentItem()->text());
     QString path = theme.emoticonsMap().key(emoList->currentItem()->text().split(' '));
-    QString f = QFileInfo(path).baseName();
+    QString f = QFileInfo(path).fileName();
     EditDialog *dlg = new EditDialog(this, i18n("Edit Emoticon"), emoList->currentItem(), path);
 
     if (dlg->exec() == QDialog::Rejected) {
@@ -340,6 +340,10 @@ void EmoticonList::editEmoticon()
             emo = dir->findResource("emoticons", themeList->currentItem()->text() + QDir::separator()  + f + ".png");
         if (emo.isNull())
             emo = dir->findResource("emoticons", themeList->currentItem()->text() + QDir::separator()  + f + ".gif");
+        if (emo.isNull())
+            emo = dir->findResource("emoticons", themeList->currentItem()->text() + QDir::separator()  + f + ".jpg");
+        if (emo.isNull())
+            emo = dir->findResource("emoticons", themeList->currentItem()->text() + QDir::separator()  + f + ".jpeg");
         if (emo.isNull()) {
             delete dlg;
             return;
