@@ -21,6 +21,7 @@
 
 #include "kio_trash.h"
 #include "testtrash.h"
+#include <kprotocolinfo.h>
 #include <ktemporaryfile.h>
 
 #include <kurl.h>
@@ -45,38 +46,39 @@
 #include <kfileitem.h>
 #include <kstandarddirs.h>
 #include <kio/chmodjob.h>
+#include <kio/directorysizejob.h>
 
 // There are two ways to test encoding things:
 // * with utf8 filenames
-// * with latin1 filenames
+// * with latin1 filenames -- not sure this still works.
 //
-//#define UTF8TEST 1
+#define UTF8TEST 1
 
 
 QString TestTrash::homeTmpDir() const
 {
-    return QDir::homePath() + "/.kde/testtrash/";
+    return QDir::homePath() + QString::fromLatin1("/.kde/testtrash/");
 }
 
 QString TestTrash::readOnlyDirPath() const
 {
-    return homeTmpDir() + QString( "readonly" );
+    return homeTmpDir() + QString::fromLatin1("readonly");
 }
 
 QString TestTrash::otherTmpDir() const
 {
     // This one needs to be on another partition
-    return "/tmp/testtrash/";
+    return QString::fromLatin1("/tmp/testtrash/");
 }
 
 QString TestTrash::utf8FileName() const
 {
-    return QString( "test" ) + QChar( 0x2153 ); // "1/3" character, not part of latin1
+    return QString::fromLatin1( "test" ) + QChar( 0x2153 ); // "1/3" character, not part of latin1
 }
 
 QString TestTrash::umlautFileName() const
 {
-    return QString( "umlaut" ) + QChar( 0xEB );
+    return QString::fromLatin1( "umlaut" ) + QChar( 0xEB );
 }
 
 static void removeFile( const QString& trashDir, const QString& fileName )
@@ -99,7 +101,8 @@ static void removeDirRecursive( const QString& dir )
 
         // Make it work even with readonly dirs, like trashReadOnlyDirFromHome() creates
         KUrl u = KUrl::fromPath( dir );
-        KFileItem fileItem( u, "inode/directory", KFileItem::Unknown );
+        //kDebug() << "chmod +0200 on" << u;
+        KFileItem fileItem(u, QString::fromLatin1("inode/directory"), KFileItem::Unknown);
         KFileItemList fileItemList;
         fileItemList.append( fileItem );
         KIO::ChmodJob* chmodJob = KIO::chmod( fileItemList, 0200, 0200, QString(), QString(), true /*recursive*/, KIO::HideProgressInfo );
@@ -113,19 +116,21 @@ static void removeDirRecursive( const QString& dir )
 
 void TestTrash::initTestCase()
 {
+#ifdef UTF8TEST
+    // Assume utf8 system
+    setenv( "LC_ALL", "en_GB.utf-8", 1 );
+    setenv( "KDE_UTF8_FILENAMES", "true", 1 );
+#else
     // Ensure a known QFile::encodeName behavior for trashUtf8FileFromHome
     // However this assume your $HOME doesn't use characters from other locales...
     setenv( "LC_ALL", "en_GB.ISO-8859-1", 1 );
-#ifdef UTF8TEST
-    setenv( "KDE_UTF8_FILENAMES", "true", 1 );
-#else
     unsetenv( "KDE_UTF8_FILENAMES" );
 #endif
 
     setenv( "KDE_FORK_SLAVES", "yes", true );
 
 
-    m_trashDir = KGlobal::dirs()->localxdgdatadir() + "Trash";
+    m_trashDir = KGlobal::dirs()->localxdgdatadir() + QString::fromLatin1("Trash");
     kDebug() << "setup: using trash directory " << m_trashDir;
 
     // Look for another writable partition than $HOME (not mandatory)
@@ -139,7 +144,7 @@ void TestTrash::initTestCase()
     m_tmpIsWritablePartition = false;
     m_tmpTrashId = -1;
     QVector<int> writableTopDirs;
-    for ( TrashImpl::TrashDirMap::ConstIterator it = trashDirs.begin(); it != trashDirs.end() ; ++it ) {
+    for ( TrashImpl::TrashDirMap::ConstIterator it = trashDirs.constBegin(); it != trashDirs.constEnd() ; ++it ) {
         if ( it.key() == 0 ) {
             QVERIFY( it.value() == m_trashDir );
             QVERIFY( topDirs.find( 0 ) == topDirs.end() );
@@ -149,28 +154,28 @@ void TestTrash::initTestCase()
             const QString topdir = topDirs[it.key()];
             if ( QFileInfo( topdir ).isWritable() ) {
                 writableTopDirs.append( it.key() );
-                if ( topdir == "/tmp/" ) {
+                if (topdir == QLatin1String("/tmp/")) {
                     m_tmpIsWritablePartition = true;
                     m_tmpTrashId = it.key();
                     kDebug() << "/tmp is on its own partition (trashid=" << m_tmpTrashId << "), some tests will be skipped";
-                    removeFile( it.value(), "/info/fileFromOther.trashinfo" );
-                    removeFile( it.value(), "/files/fileFromOther" );
-                    removeFile( it.value(), "/info/symlinkFromOther.trashinfo" );
-                    removeFile( it.value(), "/files/symlinkFromOther" );
-                    removeFile( it.value(), "/info/trashDirFromOther.trashinfo" );
-                    removeFile( it.value(), "/files/trashDirFromOther/testfile" );
-                    removeDir( it.value(), "/files/trashDirFromOther" );
+                    removeFile( it.value(), QString::fromLatin1("/info/fileFromOther.trashinfo") );
+                    removeFile( it.value(), QString::fromLatin1("/files/fileFromOther") );
+                    removeFile( it.value(), QString::fromLatin1("/info/symlinkFromOther.trashinfo") );
+                    removeFile( it.value(), QString::fromLatin1("/files/symlinkFromOther") );
+                    removeFile( it.value(), QString::fromLatin1("/info/trashDirFromOther.trashinfo") );
+                    removeFile( it.value(), QString::fromLatin1("/files/trashDirFromOther/testfile") );
+                    removeDir( it.value(), QString::fromLatin1("/files/trashDirFromOther") );
                 }
             }
         }
     }
-    for ( QVector<int>::const_iterator it = writableTopDirs.begin(); it != writableTopDirs.end(); ++it ) {
+    for ( QVector<int>::const_iterator it = writableTopDirs.constBegin(); it != writableTopDirs.constEnd(); ++it ) {
         const QString topdir = topDirs[ *it ];
         const QString trashdir = trashDirs[ *it ];
         QVERIFY( !topdir.isEmpty() );
         QVERIFY( !trashDirs.isEmpty() );
-        if ( topdir != "/tmp/" ||         // we'd prefer not to use /tmp here, to separate the tests
-               ( writableTopDirs.count() > 1 ) ) // but well, if we have no choice, take it
+        if (topdir != QLatin1String("/tmp/") ||         // we'd prefer not to use /tmp here, to separate the tests
+            (writableTopDirs.count() > 1)) // but well, if we have no choice, take it
         {
             m_otherPartitionTopDir = topdir;
             m_otherPartitionTrashDir = trashdir;
@@ -186,6 +191,7 @@ void TestTrash::initTestCase()
         kWarning() << "No writable partition other than $HOME found, some tests will be skipped" ;
 
     // Start with a clean base dir
+    kDebug() << "initial cleanup";
     removeDirRecursive( homeTmpDir() );
     removeDirRecursive( otherTmpDir() );
 
@@ -198,13 +204,14 @@ void TestTrash::initTestCase()
         kFatal() << "Couldn't create " << otherTmpDir() ;
 
     // Start with a clean trash too
+    kDebug() << "removing trash dir";
     removeDirRecursive( m_trashDir );
 }
 
 void TestTrash::urlTestFile()
 {
-    const KUrl url = TrashImpl::makeURL( 1, "fileId", QString() );
-    QCOMPARE( url.url(), QString( "trash:/1-fileId" ) );
+    const KUrl url = TrashImpl::makeURL(1, QString::fromLatin1("fileId"), QString());
+    QCOMPARE( url.url(), QString::fromLatin1("trash:/1-fileId"));
 
     int trashId;
     QString fileId;
@@ -218,7 +225,7 @@ void TestTrash::urlTestFile()
 
 void TestTrash::urlTestDirectory()
 {
-    const KUrl url = TrashImpl::makeURL( 1, "fileId", "subfile" );
+    const KUrl url = TrashImpl::makeURL( 1, QString::fromLatin1("fileId"), QString::fromLatin1("subfile") );
     QCOMPARE( url.url(), QString::fromLatin1( "trash:/1-fileId/subfile" ) );
 
     int trashId;
@@ -233,8 +240,8 @@ void TestTrash::urlTestDirectory()
 
 void TestTrash::urlTestSubDirectory()
 {
-    const KUrl url = TrashImpl::makeURL( 1, "fileId", "subfile/foobar" );
-    QCOMPARE( url.url(), QString::fromLatin1( "trash:/1-fileId/subfile/foobar" ) );
+    const KUrl url = TrashImpl::makeURL(1, QString::fromLatin1("fileId"), QString::fromLatin1("subfile/foobar"));
+    QCOMPARE(url.url(), QString::fromLatin1("trash:/1-fileId/subfile/foobar"));
 
     int trashId;
     QString fileId;
@@ -257,16 +264,16 @@ static void checkInfoFile( const QString& infoPath, const QString& origFilePath
     if ( !group.exists() )
         kFatal() << "no Trash Info group in " << info.absoluteFilePath() ;
     const QString origPath = group.readEntry( "Path" );
-    QVERIFY( !origPath.isEmpty() );
-    QVERIFY( origPath == QUrl::toPercentEncoding( origFilePath.toLatin1(), "/" ) );
-    if (origFilePath.contains(QChar(0x2153)) || origFilePath.contains('%') || origFilePath.contains("umlaut")) {
-        QVERIFY(origPath.contains('%'));
+    QVERIFY(!origPath.isEmpty());
+    QVERIFY(origPath == QString::fromLatin1(QUrl::toPercentEncoding(origFilePath, "/")));
+    if (origFilePath.contains(QChar(0x2153)) || origFilePath.contains(QLatin1Char('%')) || origFilePath.contains(QString::fromLatin1("umlaut"))) {
+        QVERIFY(origPath.contains(QLatin1Char('%')));
     } else {
-        QVERIFY(!origPath.contains('%'));
+        QVERIFY(!origPath.contains(QLatin1Char('%')));
     }
     const QString date = group.readEntry( "DeletionDate" );
-    QVERIFY( !date.isEmpty() );
-    QVERIFY( date.contains( "T" ) );
+    QVERIFY(!date.isEmpty());
+    QVERIFY(date.contains(QString::fromLatin1("T")));
 }
 
 static void createTestFile( const QString& path )
@@ -294,12 +301,12 @@ void TestTrash::trashFile( const QString& origFilePath, const QString& fileId )
     if ( !ok )
         kError() << "moving " << u << " to trash failed with error " << KIO::NetAccess::lastError() << " " << KIO::NetAccess::lastErrorString() << endl;
     QVERIFY( ok );
-    if ( origFilePath.startsWith( "/tmp" ) && m_tmpIsWritablePartition ) {
+    if (origFilePath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition) {
         kDebug() << " TESTS SKIPPED";
     } else {
-        checkInfoFile( m_trashDir + "/info/" + fileId + ".trashinfo", origFilePath );
+        checkInfoFile(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"), origFilePath);
 
-        QFileInfo files( m_trashDir + "/files/" + fileId );
+        QFileInfo files(m_trashDir + QString::fromLatin1("/files/") + fileId);
         QVERIFY( files.isFile() );
         QVERIFY( files.size() == 12 );
     }
@@ -309,18 +316,18 @@ void TestTrash::trashFile( const QString& origFilePath, const QString& fileId )
 
     QVERIFY( !metaData.isEmpty() );
     bool found = false;
-    QMap<QString, QString>::ConstIterator it = metaData.begin();
-    for ( ; it != metaData.end() ; ++it ) {
-        if ( it.key().startsWith( "trashURL" ) ) {
+    QMap<QString, QString>::ConstIterator it = metaData.constBegin();
+    for ( ; it != metaData.constEnd() ; ++it ) {
+        if (it.key().startsWith(QLatin1String("trashURL"))) {
             const QString origPath = it.key().mid( 9 );
             KUrl trashURL( it.value() );
             kDebug() << trashURL;
-            QVERIFY( !trashURL.isEmpty() );
-            QVERIFY( trashURL.protocol() == "trash" );
+            QVERIFY(!trashURL.isEmpty());
+            QVERIFY(trashURL.protocol() == QLatin1String("trash"));
             int trashId = 0;
-            if ( origFilePath.startsWith( "/tmp" ) && m_tmpIsWritablePartition )
+            if (origFilePath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition)
                 trashId = m_tmpTrashId;
-            QVERIFY( trashURL.path() == "/" + QString::number( trashId ) + '-' + fileId );
+            QCOMPARE(trashURL.path(), QString::fromLatin1("/") + QString::number(trashId) + QLatin1Char('-') + fileId);
             found = true;
         }
     }
@@ -329,16 +336,16 @@ void TestTrash::trashFile( const QString& origFilePath, const QString& fileId )
 
 void TestTrash::trashFileFromHome()
 {
-    const QString fileName = "fileFromHome";
+    const QString fileName = QString::fromLatin1("fileFromHome");
     trashFile( homeTmpDir() + fileName, fileName );
 
     // Do it again, check that we got a different id
-    trashFile( homeTmpDir() + fileName, fileName + "_1" );
+    trashFile(homeTmpDir() + fileName, fileName + QString::fromLatin1("_1"));
 }
 
 void TestTrash::trashPercentFileFromHome()
 {
-    const QString fileName = "file%2f";
+    const QString fileName = QString::fromLatin1("file%2f");
     trashFile( homeTmpDir() + fileName, fileName );
 }
 
@@ -358,7 +365,7 @@ void TestTrash::trashUmlautFileFromHome()
 
 void TestTrash::testTrashNotEmpty()
 {
-    KConfig cfg( "trashrc", KConfig::SimpleConfig );
+    KConfig cfg(QString::fromLatin1("trashrc"), KConfig::SimpleConfig);
     const KConfigGroup group = cfg.group( "Status" );
     QVERIFY( group.exists() );
     QVERIFY( group.readEntry( "Empty", true ) == false );
@@ -366,7 +373,7 @@ void TestTrash::testTrashNotEmpty()
 
 void TestTrash::trashFileFromOther()
 {
-    const QString fileName = "fileFromOther";
+    const QString fileName = QString::fromLatin1("fileFromOther");
     trashFile( otherTmpDir() + fileName, fileName );
 }
 
@@ -376,12 +383,12 @@ void TestTrash::trashFileIntoOtherPartition()
         kDebug() << " - SKIPPED";
         return;
     }
-    const QString fileName = "testtrash-file";
+    const QString fileName = QString::fromLatin1("testtrash-file");
     const QString origFilePath = m_otherPartitionTopDir + fileName;
     const QString fileId = fileName;
     // cleanup
-    QFile::remove( m_otherPartitionTrashDir + "/info/" + fileId + ".trashinfo" );
-    QFile::remove( m_otherPartitionTrashDir + "/files/" + fileId );
+    QFile::remove(m_otherPartitionTrashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"));
+    QFile::remove(m_otherPartitionTrashDir + QString::fromLatin1("/files/") + fileId);
 
     // setup
     if ( !QFile::exists( origFilePath ) )
@@ -395,9 +402,9 @@ void TestTrash::trashFileIntoOtherPartition()
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
     QVERIFY( ok );
     // Note that the Path stored in the info file is relative, on other partitions (#95652)
-    checkInfoFile( m_otherPartitionTrashDir + "/info/" + fileId + ".trashinfo", fileName );
+    checkInfoFile(m_otherPartitionTrashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"), fileName);
 
-    QFileInfo files( m_otherPartitionTrashDir + "/files/" + fileId );
+    QFileInfo files(m_otherPartitionTrashDir + QString::fromLatin1("/files/") + fileId);
     QVERIFY( files.isFile() );
     QVERIFY( files.size() == 12 );
 
@@ -406,15 +413,15 @@ void TestTrash::trashFileIntoOtherPartition()
 
     QVERIFY( !metaData.isEmpty() );
     bool found = false;
-    QMap<QString, QString>::ConstIterator it = metaData.begin();
-    for ( ; it != metaData.end() ; ++it ) {
-        if ( it.key().startsWith( "trashURL" ) ) {
+    QMap<QString, QString>::ConstIterator it = metaData.constBegin();
+    for ( ; it != metaData.constEnd() ; ++it ) {
+        if (it.key().startsWith( QLatin1String("trashURL"))) {
             const QString origPath = it.key().mid( 9 );
             KUrl trashURL( it.value() );
             kDebug() << trashURL;
             QVERIFY( !trashURL.isEmpty() );
-            QVERIFY( trashURL.protocol() == "trash" );
-            QVERIFY( trashURL.path() == QString( "/%1-%2" ).arg( m_otherPartitionId ).arg( fileId ) );
+            QVERIFY(trashURL.protocol() == QLatin1String("trash"));
+            QVERIFY(trashURL.path() == QString::fromLatin1("/%1-%2").arg( m_otherPartitionId ).arg(fileId));
             found = true;
         }
     }
@@ -424,7 +431,7 @@ void TestTrash::trashFileIntoOtherPartition()
 void TestTrash::trashFileOwnedByRoot()
 {
     KUrl u( "/etc/passwd" );
-    const QString fileId = "passwd";
+    const QString fileId = QString::fromLatin1("passwd");
 
     KIO::CopyJob* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
     job->setUiDelegate(0); // no skip dialog, thanks
@@ -432,10 +439,10 @@ void TestTrash::trashFileOwnedByRoot()
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
     QVERIFY( !ok );
     QVERIFY( KIO::NetAccess::lastError() == KIO::ERR_ACCESS_DENIED );
-    const QString infoPath( m_trashDir + "/info/" + fileId + ".trashinfo" );
+    const QString infoPath(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"));
     QVERIFY( !QFile::exists( infoPath ) );
 
-    QFileInfo files( m_trashDir + "/files/" + fileId );
+    QFileInfo files(m_trashDir + QString::fromLatin1("/files/") + fileId);
     QVERIFY( !files.exists() );
 
     QVERIFY( QFile::exists( u.path() ) );
@@ -454,13 +461,13 @@ void TestTrash::trashSymlink( const QString& origFilePath, const QString& fileId
     KIO::Job* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
     ok = job->exec();
     QVERIFY( ok );
-    if ( origFilePath.startsWith( "/tmp" ) && m_tmpIsWritablePartition ) {
+    if (origFilePath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition) {
         kDebug() << " TESTS SKIPPED";
         return;
     }
-    checkInfoFile( m_trashDir + "/info/" + fileId + ".trashinfo", origFilePath );
+    checkInfoFile(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"), origFilePath);
 
-    QFileInfo files( m_trashDir + "/files/" + fileId );
+    QFileInfo files(m_trashDir + QString::fromLatin1("/files/") + fileId);
     QVERIFY( files.isSymLink() );
     QVERIFY( files.readLink() == QFile::decodeName( target ) );
     QVERIFY( !QFile::exists( origFilePath ) );
@@ -468,19 +475,19 @@ void TestTrash::trashSymlink( const QString& origFilePath, const QString& fileId
 
 void TestTrash::trashSymlinkFromHome()
 {
-    const QString fileName = "symlinkFromHome";
+    const QString fileName = QString::fromLatin1("symlinkFromHome");
     trashSymlink( homeTmpDir() + fileName, fileName, false );
 }
 
 void TestTrash::trashSymlinkFromOther()
 {
-    const QString fileName = "symlinkFromOther";
+    const QString fileName = QString::fromLatin1("symlinkFromOther");
     trashSymlink( otherTmpDir() + fileName, fileName, false );
 }
 
 void TestTrash::trashBrokenSymlinkFromHome()
 {
-    const QString fileName = "brokenSymlinkFromHome";
+    const QString fileName = QString::fromLatin1("brokenSymlinkFromHome");
     trashSymlink( homeTmpDir() + fileName, fileName, true );
 }
 
@@ -493,21 +500,21 @@ void TestTrash::trashDirectory( const QString& origPath, const QString& fileId )
         bool ok = dir.mkdir( origPath );
         QVERIFY( ok );
     }
-    createTestFile( origPath + "/testfile" );
+    createTestFile(origPath + QString::fromLatin1("/testfile"));
     KUrl u; u.setPath( origPath );
 
     // test
     KIO::Job* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
     QVERIFY( job->exec() );
-    if ( origPath.startsWith( "/tmp" ) && m_tmpIsWritablePartition ) {
+    if (origPath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition) {
         kDebug() << " TESTS SKIPPED";
         return;
     }
-    checkInfoFile( m_trashDir + "/info/" + fileId + ".trashinfo", origPath );
+    checkInfoFile(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"), origPath);
 
-    QFileInfo filesDir( m_trashDir + "/files/" + fileId );
+    QFileInfo filesDir(m_trashDir + QString::fromLatin1("/files/") + fileId);
     QVERIFY( filesDir.isDir() );
-    QFileInfo files( m_trashDir + "/files/" + fileId + "/testfile" );
+    QFileInfo files(m_trashDir + QString::fromLatin1("/files/") + fileId + QString::fromLatin1("/testfile"));
     QVERIFY( files.exists() );
     QVERIFY( files.isFile() );
     QVERIFY( files.size() == 12 );
@@ -516,10 +523,18 @@ void TestTrash::trashDirectory( const QString& origPath, const QString& fileId )
 
 void TestTrash::trashDirectoryFromHome()
 {
-    QString dirName = "trashDirFromHome";
+    QString dirName = QString::fromLatin1("trashDirFromHome");
     trashDirectory( homeTmpDir() + dirName, dirName );
     // Do it again, check that we got a different id
-    trashDirectory( homeTmpDir() + dirName, dirName + "_1" );
+    trashDirectory(homeTmpDir() + dirName, dirName + QString::fromLatin1("_1"));
+}
+
+void TestTrash::trashDotDirectory()
+{
+    QString dirName = QString::fromLatin1(".dotTrashDirFromHome");
+    trashDirectory( homeTmpDir() + dirName, dirName );
+    // Do it again, check that we got a different id
+    // TODO trashDirectory(homeTmpDir() + dirName, dirName + QString::fromLatin1("_1"));
 }
 
 void TestTrash::trashReadOnlyDirFromHome()
@@ -529,18 +544,18 @@ void TestTrash::trashReadOnlyDirFromHome()
     bool ok = dir.mkdir( dirName );
     QVERIFY( ok );
     // #130780
-    const QString subDirPath = dirName + "/readonly_subdir";
+    const QString subDirPath = dirName + QString::fromLatin1("/readonly_subdir");
     ok = dir.mkdir( subDirPath );
     QVERIFY( ok );
-    createTestFile( subDirPath + "/testfile_in_subdir" );
+    createTestFile(subDirPath + QString::fromLatin1("/testfile_in_subdir"));
     ::chmod( QFile::encodeName( subDirPath ), 0500 );
 
-    trashDirectory( dirName, "readonly" );
+    trashDirectory(dirName, QString::fromLatin1("readonly"));
 }
 
 void TestTrash::trashDirectoryFromOther()
 {
-    QString dirName = "trashDirFromOther";
+    QString dirName = QString::fromLatin1("trashDirFromOther");
     trashDirectory( otherTmpDir() + dirName, dirName );
 }
 
@@ -566,13 +581,13 @@ void TestTrash::delRootFile()
     bool ok = KIO::NetAccess::synchronousRun(delJob, 0);
     QVERIFY( ok );
 
-    QFileInfo file( m_trashDir + "/files/fileFromHome" );
+    QFileInfo file( m_trashDir + QString::fromLatin1("/files/fileFromHome") );
     QVERIFY( !file.exists() );
-    QFileInfo info( m_trashDir + "/info/fileFromHome.trashinfo" );
+    QFileInfo info( m_trashDir + QString::fromLatin1("/info/fileFromHome.trashinfo") );
     QVERIFY( !info.exists() );
 
     // trash it again, we might need it later
-    const QString fileName = "fileFromHome";
+    const QString fileName = QString::fromLatin1("fileFromHome");
     trashFile( homeTmpDir() + fileName, fileName );
 }
 
@@ -584,11 +599,11 @@ void TestTrash::delFileInDirectory()
     QVERIFY( !ok );
     QVERIFY( KIO::NetAccess::lastError() == KIO::ERR_ACCESS_DENIED );
 
-    QFileInfo dir( m_trashDir + "/files/trashDirFromHome" );
+    QFileInfo dir( m_trashDir + QString::fromLatin1("/files/trashDirFromHome") );
     QVERIFY( dir.exists() );
-    QFileInfo file( m_trashDir + "/files/trashDirFromHome/testfile" );
+    QFileInfo file( m_trashDir + QString::fromLatin1("/files/trashDirFromHome/testfile") );
     QVERIFY( file.exists() );
-    QFileInfo info( m_trashDir + "/info/trashDirFromHome.trashinfo" );
+    QFileInfo info( m_trashDir + QString::fromLatin1("/info/trashDirFromHome.trashinfo") );
     QVERIFY( info.exists() );
 }
 
@@ -599,15 +614,15 @@ void TestTrash::delDirectory()
     bool ok = KIO::NetAccess::synchronousRun(delJob, 0);
     QVERIFY( ok );
 
-    QFileInfo dir( m_trashDir + "/files/trashDirFromHome" );
+    QFileInfo dir( m_trashDir + QString::fromLatin1("/files/trashDirFromHome") );
     QVERIFY( !dir.exists() );
-    QFileInfo file( m_trashDir + "/files/trashDirFromHome/testfile" );
+    QFileInfo file( m_trashDir + QString::fromLatin1("/files/trashDirFromHome/testfile") );
     QVERIFY( !file.exists() );
-    QFileInfo info( m_trashDir + "/info/trashDirFromHome.trashinfo" );
+    QFileInfo info( m_trashDir + QString::fromLatin1("/info/trashDirFromHome.trashinfo") );
     QVERIFY( !info.exists() );
 
     // trash it again, we'll need it later
-    QString dirName = "trashDirFromHome";
+    QString dirName = QString::fromLatin1("trashDirFromHome");
     trashDirectory( homeTmpDir() + dirName, dirName );
 }
 
@@ -638,7 +653,7 @@ void TestTrash::statRoot()
     QVERIFY( item.isReadable() );
     QVERIFY( item.isWritable() );
     QVERIFY( !item.isHidden() );
-    QVERIFY( item.name() == "." );
+    QCOMPARE(item.name(), QString::fromLatin1("."));
 }
 
 void TestTrash::statFileInRoot()
@@ -654,7 +669,7 @@ void TestTrash::statFileInRoot()
     QVERIFY( item.isReadable() );
     QVERIFY( !item.isWritable() );
     QVERIFY( !item.isHidden() );
-    QVERIFY( item.text() == "fileFromHome" );
+    QCOMPARE(item.text(), QString::fromLatin1("fileFromHome"));
 }
 
 void TestTrash::statDirectoryInRoot()
@@ -669,7 +684,7 @@ void TestTrash::statDirectoryInRoot()
     QVERIFY( item.isReadable() );
     QVERIFY( !item.isWritable() );
     QVERIFY( !item.isHidden() );
-    QVERIFY( item.text() == "trashDirFromHome" );
+    QCOMPARE(item.text(), QString::fromLatin1("trashDirFromHome"));
 }
 
 void TestTrash::statSymlinkInRoot()
@@ -680,11 +695,11 @@ void TestTrash::statSymlinkInRoot()
     QVERIFY( ok );
     KFileItem item( entry, url );
     QVERIFY( item.isLink() );
-    QVERIFY( item.linkDest() == "/tmp" );
+    QCOMPARE(item.linkDest(), QString::fromLatin1("/tmp"));
     QVERIFY( item.isReadable() );
     QVERIFY( !item.isWritable() );
     QVERIFY( !item.isHidden() );
-    QVERIFY( item.text() == "symlinkFromHome" );
+    QCOMPARE(item.text(), QString::fromLatin1("symlinkFromHome"));
 }
 
 void TestTrash::statFileInDirectory()
@@ -699,12 +714,12 @@ void TestTrash::statFileInDirectory()
     QVERIFY( item.isReadable() );
     QVERIFY( !item.isWritable() );
     QVERIFY( !item.isHidden() );
-    QVERIFY( item.text() == "testfile" );
+    QCOMPARE(item.text(), QString::fromLatin1("testfile"));
 }
 
 void TestTrash::copyFromTrash( const QString& fileId, const QString& destPath, const QString& relativePath )
 {
-    KUrl src( "trash:/0-" + fileId );
+    KUrl src(QString::fromLatin1("trash:/0-") + fileId);
     if ( !relativePath.isEmpty() )
         src.addPath( relativePath );
     KUrl dest;
@@ -717,10 +732,10 @@ void TestTrash::copyFromTrash( const QString& fileId, const QString& destPath, c
     KIO::Job* job = KIO::copyAs( src, dest, KIO::HideProgressInfo );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( ok );
-    QString infoFile( m_trashDir + "/info/" + fileId + ".trashinfo" );
+    QString infoFile( m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo") );
     QVERIFY( QFile::exists(infoFile) );
 
-    QFileInfo filesItem( m_trashDir + "/files/" + fileId );
+    QFileInfo filesItem( m_trashDir + QString::fromLatin1("/files/") + fileId );
     QVERIFY( filesItem.exists() );
 
     QVERIFY( QFile::exists(destPath) );
@@ -731,7 +746,7 @@ void TestTrash::copyFileFromTrash()
 // To test case of already-existing destination, uncomment this.
 // This brings up the "rename" dialog though, so it can't be fully automated
 #if 0
-    const QString destPath = otherTmpDir() + "fileFromHome_copied";
+    const QString destPath = otherTmpDir() + QString::fromLatin1("fileFromHome_copied");
     copyFromTrash( "fileFromHome", destPath );
     QVERIFY( QFileInfo( destPath ).isFile() );
     QVERIFY( QFileInfo( destPath ).size() == 12 );
@@ -740,29 +755,29 @@ void TestTrash::copyFileFromTrash()
 
 void TestTrash::copyFileInDirectoryFromTrash()
 {
-    const QString destPath = otherTmpDir() + "testfile_copied";
-    copyFromTrash( "trashDirFromHome", destPath, "testfile" );
+    const QString destPath = otherTmpDir() + QString::fromLatin1("testfile_copied");
+    copyFromTrash(QString::fromLatin1("trashDirFromHome"), destPath, QString::fromLatin1("testfile"));
     QVERIFY( QFileInfo( destPath ).isFile() );
     QVERIFY( QFileInfo( destPath ).size() == 12 );
 }
 
 void TestTrash::copyDirectoryFromTrash()
 {
-    const QString destPath = otherTmpDir() + "trashDirFromHome_copied";
-    copyFromTrash( "trashDirFromHome", destPath );
+    const QString destPath = otherTmpDir() + QString::fromLatin1("trashDirFromHome_copied");
+    copyFromTrash(QString::fromLatin1("trashDirFromHome"), destPath);
     QVERIFY( QFileInfo( destPath ).isDir() );
 }
 
 void TestTrash::copySymlinkFromTrash()
 {
-    const QString destPath = otherTmpDir() + "symlinkFromHome_copied";
-    copyFromTrash( "symlinkFromHome", destPath );
+    const QString destPath = otherTmpDir() + QString::fromLatin1("symlinkFromHome_copied");
+    copyFromTrash(QString::fromLatin1("symlinkFromHome"), destPath);
     QVERIFY( QFileInfo( destPath ).isSymLink() );
 }
 
 void TestTrash::moveFromTrash( const QString& fileId, const QString& destPath, const QString& relativePath )
 {
-    KUrl src( "trash:/0-" + fileId );
+    KUrl src( QString::fromLatin1("trash:/0-") + fileId );
     if ( !relativePath.isEmpty() )
         src.addPath( relativePath );
     KUrl dest;
@@ -1032,6 +1047,13 @@ void TestTrash::emptyTrash()
     // trash would still empty the other trash directories in other partitions.
     // So we can't activate this test by default.
 #if 0
+
+    // To make this test standalone
+    trashFileFromHome();
+
+    // #167051: orphaned files
+    createTestFile( m_trashDir + "/files/testfile_nometadata" );
+
     QByteArray packedArgs;
     QDataStream stream( &packedArgs, QIODevice::WriteOnly );
     stream << (int)1;
@@ -1046,11 +1068,21 @@ void TestTrash::emptyTrash()
     QVERIFY( !QFile::exists( m_trashDir + "/files/fileFromHome" ) );
     QVERIFY( !QFile::exists( m_trashDir + "/files/readonly" ) );
     QVERIFY( !QFile::exists( m_trashDir + "/info/readonly.trashinfo" ) );
+    QVERIFY(QDir(m_trashDir + "/info").entryList(QDir::NoDotAndDotDot|QDir::AllEntries).isEmpty());
+    QVERIFY(QDir(m_trashDir + "/files").entryList(QDir::NoDotAndDotDot|QDir::AllEntries).isEmpty());
+
 #else
     kDebug() << " : SKIPPED";
 #endif
 }
 
+void TestTrash::testTrashSize()
+{
+    KIO::DirectorySizeJob* job = KIO::directorySize(KUrl("trash:/"));
+    QVERIFY(job->exec());
+    QVERIFY(job->totalSize() < 1000000000 /*1GB*/); // #157023
+}
+
 static void checkIcon( const KUrl& url, const QString& expectedIcon )
 {
     QString icon = KMimeType::iconNameForUrl( url );
@@ -1059,6 +1091,7 @@ static void checkIcon( const KUrl& url, const QString& expectedIcon )
 
 void TestTrash::testIcons()
 {
+    QCOMPARE(KProtocolInfo::icon("trash"), QString("user-trash-full") ); // #100321
     checkIcon( KUrl("trash:/"), "user-trash-full" ); // #100321
     checkIcon( KUrl("trash:/foo/"), "inode-directory" );
 }
