@@ -1,6 +1,6 @@
 /*
   This file is part of the Nepomuk KDE project.
-  Copyright (C) 2007 Sebastian Trueg <trueg@kde.org>
+  Copyright (C) 2007-2009 Sebastian Trueg <trueg@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -19,7 +19,7 @@
 
 #include "searchthread.h"
 #include "term.h"
-#include "qurlhash.h"
+#include "nfo.h"
 
 #include <Nepomuk/ResourceManager>
 #include <Nepomuk/Resource>
@@ -40,8 +40,10 @@
 #include <Soprano/Vocabulary/NAO>
 #include <Soprano/Vocabulary/XMLSchema>
 #include <Soprano/Vocabulary/OWL>
+#include <Soprano/Vocabulary/Xesam>
 
 #include <KDebug>
+#include <KRandom>
 
 #include <QtCore/QTime>
 
@@ -50,7 +52,7 @@
 // FIXME: With our cutoff score we might miss results that are hit multiple times and thus, would get their
 //        score increased
 
-#warning Make query optimization methods return an invalid term if the query cannot be resolved and handle this as no results
+// FIXME: Make query optimization methods return an invalid term if the query cannot be resolved and handle this as no results
 
 using namespace Soprano;
 
@@ -154,6 +156,16 @@ namespace {
     }
 
 
+    QString wrapInInstanceBaseGraphQuery( const QString& query, int cnt = 0 )
+    {
+        // TODO: better use a member variable to count the used graphs
+        return QString( "graph ?g%1 { %2 } . ?g%1 a %3 . " )
+            .arg( cnt > 0 ? cnt : KRandom::random() )
+            .arg( query )
+            .arg( Soprano::Node::resourceToN3( Soprano::Vocabulary::NRL::InstanceBase() ) );
+    }
+
+
     QString createGraphPattern( const Nepomuk::Search::SearchNode& node, int& varCnt, const QString& varName = QString( "?r" ) )
     {
         switch( node.term.type() ) {
@@ -183,35 +195,48 @@ namespace {
                             filter += QString( "^^<%1>" ).arg( prop.literalRangeType().dataTypeUri().toString() );
                     }
 
-                    return QString( "%1 <%2> ?var%3 . FILTER(%4) . " )
-                        .arg( varName )
-                        .arg( QString::fromAscii( node.term.property().toEncoded() ) )
-                        .arg( varCnt )
-                        .arg( filter );
+                    return wrapInInstanceBaseGraphQuery( QString( "%1 <%2> ?var%3 . FILTER(%4) . " )
+                                                         .arg( varName )
+                                                         .arg( QString::fromAscii( node.term.property().toEncoded() ) )
+                                                         .arg( varCnt )
+                                                         .arg( filter ) );
                 }
                 else {
                     if ( subTerm.type() == Nepomuk::Search::Term::ResourceTerm ) {
-                        return QString( "%1 <%2> <%3> . " )
-                            .arg( varName )
-                            .arg( QString::fromAscii( node.term.property().toEncoded() ) )
-                            .arg( QString::fromAscii( subTerm.resource().toEncoded() ) );
+                        return wrapInInstanceBaseGraphQuery( QString( "%1 <%2> <%3> . " )
+                                                             .arg( varName )
+                                                             .arg( QString::fromAscii( node.term.property().toEncoded() ) )
+                                                             .arg( QString::fromAscii( subTerm.resource().toEncoded() ) ) );
                     }
                     else if ( Nepomuk::Types::Property( node.term.property() ).range().isValid() ) {
-                        return QString( "%7 <%1> ?x . { ?x <%2> \"%3\"^^<%4> . } UNION { ?x <%5> \"%3\"^^<%4>.  } UNION { ?x <%6> \"%3\"^^<%4> . }" )
-                            .arg( QString::fromAscii( node.term.property().toEncoded() ) )
-                            .arg( Soprano::Vocabulary::RDFS::label().toString() )
-                            .arg( subTerm.value().toString() )
-                            .arg( Soprano::Vocabulary::XMLSchema::string().toString() )
-                            .arg( Soprano::Vocabulary::NAO::prefLabel().toString() )
-                            .arg( Soprano::Vocabulary::NAO::identifier().toString() )
-                            .arg( varName );
+                        return wrapInInstanceBaseGraphQuery( QString( "%1 %2 ?x . " )
+                                                             .arg( varName )
+                                                             .arg( Soprano::Node::resourceToN3( node.term.property() ) ) )
+                            + wrapInInstanceBaseGraphQuery( QString( "{ ?x %1 \"%2\"^^%3 . }"
+                                                                     " UNION "
+                                                                     "{ ?x %4 \"%2\"^^%3.  }"
+                                                                     " UNION "
+                                                                     "{ ?x %5 \"%2\"^^%3 . }" )
+                                                            .arg( Soprano::Node::resourceToN3( Soprano::Vocabulary::RDFS::label() ) )
+                                                            .arg( subTerm.value().toString() )
+                                                            .arg( Soprano::Node::resourceToN3( Soprano::Vocabulary::XMLSchema::string() ) )
+                                                            .arg( Soprano::Node::resourceToN3( Soprano::Vocabulary::NAO::prefLabel() ) )
+                                                            .arg( Soprano::Node::resourceToN3( Soprano::Vocabulary::NAO::identifier() ) ) );
                     }
                     else {
-                        return QString( "%1 <%2> \"%3\"^^<%4> . " )
-                            .arg( varName )
-                            .arg( QString::fromAscii( node.term.property().toEncoded() ) )
-                            .arg( subTerm.value().toString() )
-                            .arg( Nepomuk::Types::Property( node.term.property() ).literalRangeType().dataTypeUri().toString() );
+                        //
+                        // Nepomuk still treats all plain literals as xsd string typed literals,
+                        // i.e. Resource only saves typed literals, never plain ones, even if the
+                        // property is defined to range to a plain one.
+                        //
+                        Nepomuk::Types::Property p( node.term.property() );
+                        return wrapInInstanceBaseGraphQuery( QString( "%1 <%2> \"%3\"^^<%4> . " )
+                                                             .arg( varName )
+                                                             .arg( QString::fromAscii( node.term.property().toEncoded() ) )
+                                                             .arg( subTerm.value().toString() )
+                                                             .arg( p.literalRangeType().dataTypeUri() == Soprano::Vocabulary::RDFS::Literal()
+                                                                   ? Soprano::Vocabulary::XMLSchema::string().toString()
+                                                                   : p.literalRangeType().dataTypeUri().toString() ) );
                     }
                 }
             }
@@ -435,12 +460,15 @@ Nepomuk::Search::Term Nepomuk::Search::SearchThread::resolveValues( const Term&
 
                 // rdfs:label has a higher priority than any other property
                 // TODO: without being able to query the resource type simple searching for term.value() is waaaaay to slow
+                // FIXME: We CAN query the type now!
                 //QString query = QString( "%1:\"%2\"^4 \"%2\"" )
-                QString query = QString( "%1:\"%2\" OR %3:\"%2\" OR %4:\"%2\"" )
+                QString query = QString( "%1:\"%2\" OR %3:\"%2\" OR %4:\"%2\" OR %5:\"%2\" OR %6:\"%2\"" )
                                 .arg( luceneQueryEscape( Soprano::Vocabulary::RDFS::label() ) )
                                 .arg( term.subTerms().first().value().toString() )
                                 .arg( luceneQueryEscape( Soprano::Vocabulary::NAO::prefLabel() ) )
-                                .arg( luceneQueryEscape( Soprano::Vocabulary::NAO::identifier() ) );
+                                .arg( luceneQueryEscape( Soprano::Vocabulary::NAO::identifier() ) )
+                                .arg( luceneQueryEscape( Soprano::Vocabulary::Xesam::name() ) )
+                                .arg( luceneQueryEscape( Nepomuk::Vocabulary::NFO::fileName() ) );
                 Soprano::QueryResultIterator hits = ResourceManager::instance()->mainModel()->executeQuery( query,
                                                                                                             Soprano::Query::QueryLanguageUser,
                                                                                                             "lucene" );
@@ -699,15 +727,16 @@ QList<QUrl> Nepomuk::Search::SearchThread::matchFieldName( const QString& field
 
     // Step 1: see if we have a direct match to a predicate label
     //         there is no need in selecting unused properties
+    // We use the ugly FILTER to support both Soprano 2.3 (which supports plain literals) and earlier (which had only typed literals)
     QString query = QString( "select distinct ?p where { "
                              "?p <%1> <%2> . "
-                             "?p <%3> \"%4\"^^<%5> . "
+                             "?p <%3> ?label . "
+                             "FILTER(STR(?label) = \"%4\") . "
                              "?x ?p ?y . }" )
                     .arg( Soprano::Vocabulary::RDF::type().toString() )
                     .arg( Soprano::Vocabulary::RDF::Property().toString() )
                     .arg( Soprano::Vocabulary::RDFS::label().toString() )
-                    .arg( field )
-                    .arg( Soprano::Vocabulary::XMLSchema::string().toString() );
+                    .arg( field );
     kDebug() << "Direct match query:" << query;
 
     Soprano::QueryResultIterator labelHits = ResourceManager::instance()->mainModel()->executeQuery( query,
@@ -770,9 +799,8 @@ QList<QUrl> Nepomuk::Search::SearchThread::matchFieldName( const QString& field
 QString Nepomuk::Search::SearchThread::createSparqlQuery( const Nepomuk::Search::SearchNode& node )
 {
     int varCnt = 0;
-    return QString( "select distinct ?r %1 where { graph ?g { ?r a ?type . } . ?g a <%2> . %3 %4 }" )
+    return QString( "select distinct ?r %1 where { %3 %4 }" )
         .arg( buildRequestPropertyVariableList() )
-        .arg( Soprano::Vocabulary::NRL::InstanceBase().toString() )
         .arg( createGraphPattern( node, varCnt ) )
         .arg( buildRequestPropertyPatterns() );
 }
