@@ -25,7 +25,6 @@
 #include <Soprano/Version>
 #include <Soprano/StorageModel>
 #include <Soprano/Error/Error>
-#include <Soprano/Vocabulary/Xesam>
 #include <Soprano/Vocabulary/RDF>
 
 #ifdef HAVE_SOPRANO_INDEX
@@ -49,7 +48,7 @@
 namespace {
     QString createStoragePath( const QString& repositoryId )
     {
-        return KStandardDirs::locateLocal( "data", "nepomuk/repository/" + repositoryId + "/" );
+        return KStandardDirs::locateLocal( "data", "nepomuk/repository/" + repositoryId + '/' );
     }
 
 #if defined(HAVE_SOPRANO_INDEX) && defined(HAVE_CLUCENE) && SOPRANO_IS_VERSION(2,1,64)
@@ -67,6 +66,11 @@ namespace {
     private:
         Soprano::Index::IndexFilterModel* m_model;
     };
+
+    // The index version that is written by this implementation. Increase this if a major bug
+    // was fixed in the CLucene index or new information needs to be written into the index
+    // (for example using Soprano::IndexFilterModel::addForceIndexPredicate.)
+    const int s_indexVersion = 2;
 #endif
 }
 
@@ -147,37 +151,32 @@ void Nepomuk::Repository::open()
     KStandardDirs::makeDir( indexPath );
     KStandardDirs::makeDir( storagePath );
 
-    kDebug(300002) << "opening repository '" << name() << "' at '" << m_basePath << "'";
+    kDebug() << "opening repository '" << name() << "' at '" << m_basePath << "'";
 
 
     // open storage
     // =================================
     m_model = backend->createModel( QList<Soprano::BackendSetting>() << Soprano::BackendSetting( Soprano::BackendOptionStorageDir, storagePath ) );
     if ( !m_model ) {
-        kDebug(300002) << "Unable to create model for repository" << name();
+        kDebug() << "Unable to create model for repository" << name();
         m_state = CLOSED;
         emit opened( this, false );
         return;
     }
 
-    kDebug(300002) << "Successfully created new model for repository" << name();
+    kDebug() << "Successfully created new model for repository" << name();
 
 #if defined(HAVE_SOPRANO_INDEX) && defined(HAVE_CLUCENE)
     m_analyzer = new CLuceneAnalyzer();
     m_index = new Soprano::Index::CLuceneIndex( m_analyzer );
 
     if ( m_index->open( indexPath, true ) ) {
-        kDebug(300002) << "Successfully created new index for repository" << name();
+        kDebug() << "Successfully created new index for repository" << name();
         m_indexModel = new Soprano::Index::IndexFilterModel( m_index, m_model );
 
         // FIXME: find a good value here
         m_indexModel->setTransactionCacheSize( 100 );
 
-#if SOPRANO_IS_VERSION(2,0,99)
-        // no need for the whole content in the store, we only need it for searching
-        // (compare the strigi backend)
-        m_indexModel->addIndexOnlyPredicate( Soprano::Vocabulary::Xesam::asText() );
-#endif
 #if SOPRANO_IS_VERSION(2,1,64)
         m_indexModel->addForceIndexPredicate( Soprano::Vocabulary::RDF::type() );
 #endif
@@ -185,7 +184,7 @@ void Nepomuk::Repository::open()
         setParentModel( m_indexModel );
     }
     else {
-        kDebug(300002) << "Unable to open CLucene index for repo '" << name() << "': " << m_index->lastError();
+        kDebug() << "Unable to open CLucene index for repo '" << name() << "': " << m_index->lastError();
         delete m_index;
         delete m_model;
         m_index = 0;
@@ -287,7 +286,7 @@ void Nepomuk::Repository::rebuildingIndexFinished()
 
     // save our new settings
     KConfigGroup repoConfig = KSharedConfig::openConfig( "nepomukserverrc" )->group( name() + " Settings" );
-    repoConfig.writeEntry( "rebuilt index for type indexing", true );
+    repoConfig.writeEntry( "index version", s_indexVersion );
 
     // inform that we are open and done
     m_state = OPEN;
@@ -358,7 +357,7 @@ bool Nepomuk::Repository::rebuildIndexIfNecessary()
 {
 #if defined(HAVE_SOPRANO_INDEX) && defined(HAVE_CLUCENE) && SOPRANO_IS_VERSION(2,1,64)
     KConfigGroup repoConfig = KSharedConfig::openConfig( "nepomukserverrc" )->group( name() + " Settings" );
-    if( !repoConfig.readEntry( "rebuilt index for type indexing", false ) ) {
+    if( repoConfig.readEntry( "index version", 1 ) < s_indexVersion ) {
         KNotification::event( "rebuldingNepomukIndex",
                               i18nc("@info - notification message",
                                     "Rebuilding Nepomuk full text search index for new features. This will only be done once and might take a while."),
@@ -379,11 +378,11 @@ const Soprano::Backend* Nepomuk::Repository::activeSopranoBackend()
     QString backendName = KSharedConfig::openConfig( "nepomukserverrc" )->group( "Basic Settings" ).readEntry( "Soprano Backend", "sesame2" );
     const Soprano::Backend* backend = ::Soprano::discoverBackendByName( backendName );
     if ( !backend ) {
-        kDebug(300002) << "(Nepomuk::Core::Core) could not find backend" << backendName << ". Falling back to default.";
+        kDebug() << "(Nepomuk::Core::Core) could not find backend" << backendName << ". Falling back to default.";
         backend = ::Soprano::usedBackend();
     }
     if ( !backend ) {
-        kDebug(300002) << "(Nepomuk::Core::Core) could not find a backend.";
+        kDebug() << "(Nepomuk::Core::Core) could not find a backend.";
     }
     return backend;
 }
